Learn R Programming

ggpmisc (version 1.0.0)

check_limit_to: Check limit.to and fullrange arguments

Description

Implement backwards compatibility and support override of fullrange by limit.to.

Usage

check_limit_to(fullrange, limit.to = NULL, orientation = "x")

Arguments

fullrange

logical Should the fit prediction span the full range of the plot, or just the range of the explanatory variable?

limit.to

character or numeric If character one of "", "x", "y" or "xy". Should the fit prediction be constrained to the range of the variables mapped to x and/or y in each data group? If numeric, the new data values to use for the explanatory variable when computing the predicted line and confidence band. When set, limit.to silently overrides fullrange!

orientation

character Either "x" or "y" controlling the default for formula. The letter indicates the aesthetic considered the explanatory variable in the model fit.