Learn R Programming

ggpmisc (version 1.0.0)

extract_weights: Extract prior and fitted weights

Description

Extract the prior and fitted weights from a fitted model object.

Usage

extract_weights(fm, n.row)

Value

A list with two named members: rob.weight.vals the weights actually used to weight residuals, either user supplied or computed, and

weight.vals the prior weights passed as argument. When not available the vectors are filled with NA_real_ values.

Arguments

fm

a fitted model object of a supported class.

n.row

interger The expected length of the weights vectors to extract.