Learn R Programming

ggpmisc (version 1.0.0)

show_labels: Message listing non-missing labels

Description

Issue a message listing labels that are available using their "nicknames".

Usage

show_labels(z, show.what = NULL, stat.name = "stat")

Arguments

z

data.frame from which to extract names of columns.

show.what

character One of "nicknames", "colnames" or "none".

stat.name

character Name to be included in the message text.

Details

Columns of z with names ending in .label and containing non-missing values are reported after replacing column names by the shortnames used in function use_label() and f_use_label().

Computed variables and their names can vary depending on the method used to fit a model or the output.type in use. They can also depend for a given method on other arguments passed when fitting a model or extracting estimates and other computed values. A message is issued listing the short names for formatted labels as recognized by functions use_label() and use_label().