Extract the prior and fitted weights from a fitted model object.
extract_weights(fm, n.row)A list with two named members: rob.weight.vals the weights
actually used to weight residuals, either user supplied or computed, and
weight.vals the prior weights passed as argument. When not available
the vectors are filled with NA_real_ values.
a fitted model object of a supported class.
interger The expected length of the weights vectors to extract.