The new facilities for cleanly defining new stats and geoms added to
'ggplot2' in version 2.0.0 have made this package easy to code. However, this
means that this package requires version 2.0.0 or later of ggplot2.Extensions provided:
- Function for conversion of time series data into data frames that can be
plotted with ggplot.
- Stats for locating and tagging "peaks" and "valleys" (local or global
maxima and minima).
- Stat for generating labels from a
lm() model fit, including
formatted equation. By default labels are expressions but tikz device is
supported optionally with LaTeX formatted labels.
- Stats for extracting information from a any model fit supported by
package 'broom'.
- "Debug" stats and a "debug" geom that print to the console a summary
ot their
data input.
The stats for peaks and valleys are coded so as to work correctly both with
numeric and POSIXct variables mapped to the x aesthetic. Special handling was
needed as text labels are generated from the data.